# ---------------------------------------------------------------------------
# RemoveOnclick - A Plugin for Movable Type
#
# <MTCRemoveOnclick> container tag removes onclick attribute in the img tag.
#
# Release 1.1
# December 19, 2004
#
# Author: nlog(n)
# http://nlogn.ath.cx/
# mailto:n@nlogn.ath.cx
# ---------------------------------------------------------------------------

package MT::Plugins::RemoveOnclick;

use strict;
use MT::Template::Context;
MT::Template::Context->add_container_tag(CRemoveOnclick => \&CRemoveOnclick);

use vars qw($VERSION);
$VERSION = '1.1';
my $name = 'RemoveOnclick';

if (MT->version_number >= 3) {
  require MT::Plugin;
  my $plugin = MT::Plugin->new({
    name => "$name $VERSION",
    description => 'Removes onclick and onkeypress attribute in the img tag.',
    doc_link => 'http://nlogn.ath.cx/plugins/removeonclick/'
  });
  MT->add_plugin($plugin);
}

sub CRemoveOnclick {
  my ($ctx, $args) = @_;

  my $tokens = $ctx->stash('tokens');
  my $builder = $ctx->stash('builder');

  defined(my $out = $builder->build($ctx, $tokens))
    or return $ctx->error($builder->errstr);

  $out =~ s/\s+onclick=".*?"//ig;
  $out =~ s/\s+onkeypress=".*?"//ig;

  $out;
}

1;
